Skip to contents

Print Submission Profile

Usage

# S3 method for class 'submission_profile'
print(x, ...)

Arguments

x

A submission_profile object.

...

Ignored.

Value

Invisibly returns x. Called for its side effect of printing a summary of the submission profile (authority, submission type, pillar weights, ready band, required indicators, and minimum coverage) to the console.