powered by
Returns a summary of all supported regulatory authorities with their full names, countries, and number of available submission types.
list_authorities()
A tibble with columns: authority, full_name, country, n_submission_types.
authority
full_name
country
n_submission_types
Run the code above in your browser using DataLab