Learn R Programming

r4subprofile (version 0.1.0)

print.submission_profile: Print Submission Profile

Description

Print Submission Profile

Usage

# S3 method for submission_profile
print(x, ...)

Value

Invisibly returns x. Called for its side effect of printing a summary of the submission profile (authority, submission type, pillar weights, ready band, required indicators, and minimum coverage) to the console.

Arguments

x

A submission_profile object.

...

Ignored.