Learn R Programming

r4subprofile (version 0.1.0)

profile_summary: Summarize a Submission Profile

Description

Prints a formatted summary of a regulatory submission profile including authority details, pillar weights, decision bands, and requirements.

Usage

profile_summary(profile)

Value

The profile object, invisibly.

Arguments

profile

A submission_profile object.

Examples

Run this code
prof <- submission_profile("FDA", "NDA")
profile_summary(prof)

Run the code above in your browser using DataLab